#!/bin/bash
#
#  A simple wrapper around the PNFS-to-Chimera migration test tool.
#
#  To use this tool:
#
#  1. Make a file containing a list of the PNFS IDs of all
#     files you wish to test, something like:
#
#        pnfsDump files -f > /tmp/all-files-in-PNFS
#
#     NB. pnfsDump must be run on the same machine as the PNFS dbserver
#     daemons.
#
#  2. Install this script and accompanying .jar file on a machine with
#     PNFS mounted and that has access to the Chimera database.
#
#  3. Adjust /opt/d-cache/config/chimera-config.xml so it points to the
#     Chimera database.  This should only be necessary if Chimera
#     database is not running on localhost.
#
#  4. Run this script giving it the filename containing the PNFS IDs;
#     for example:
#
#        ./migration-check.sh /tmp/all-files-in-PNFS
#
#  5. the migration-check.sh will accept an option "-k".  Specifying
#     this option will prevent migration-check from halting on the
#     first error.

#  Default location for dCache.
default_home=/opt/d-cache

#  Absolute path to the directory this script is running from.
BASE_DIR=$(cd $(dirname $0); pwd)

#  Ask dCache for the externalLibsClassPath.
export ourHomeDir=${DCACHE_HOME:=$default_home}
. $DCACHE_HOME/classes/extern.classpath

LOG4J_FILE=${DCACHE_HOME}/config/log4j.properties

THIS_JAR=$BASE_DIR/migration-check.jar
DCACHE_JAR=$DCACHE_HOME/classes/dcache.jar

CLASS=org.dcache.chimera.migration.Comparator
OPTIONS=-Dlog4j.configuration=file:$LOG4J_FILE

java -cp $THIS_JAR:$DCACHE_JAR:$externalLibsClassPath $OPTIONS $CLASS "$@"
